@@ -5,10 +5,10 @@ knitr::opts_chunk$set(comment = "#>", collapse = TRUE)
 library(configr)
 library(BioInstaller)
 blast.databases <- system.file('extdata', 
-  'databases/blast.toml', package = 'BioInstaller')
+  'config/db/db_blast.toml', package = 'BioInstaller')
 
-read.config(blast.databases)$blast_db_nr$source_url
-read.config(blast.databases, glue.parse = TRUE)$blast_db_nr$source_url
+read.config(blast.databases)$db_blast_nr$source_url
+read.config(blast.databases, glue.parse = TRUE)$db_blast_nr$source_url
 mask.github <- tempfile()
 file.create(mask.github)
 install.bioinfo(nongithub.cfg = blast.databases, github.cfg = mask.github,
